empulse.datasets#

The datasets module contains a collection of datasets which can be used for value-driven and cost-sensitive learning. All datasets are based on real-world data.

Dataset

Container object for datasets returned by the load / fetch functions.

get_data_home

Return the path to the empulse data directory.

load_churn_tv_subscriptions

Load the TV Subscription Churn dataset (binary classification).

load_upsell_bank_telemarketing

Load the bank telemarketing dataset (binary classification).

load_credit_scoring_pakdd

Load the credit scoring PAKDD 2009 competition dataset (binary classification).

fetch_give_me_some_credit

Fetch the "Give Me Some Credit" dataset from OpenML (binary classification).

fetch_iranian_churn

Fetch the Iranian Churn dataset from the UCI ML Repository (binary classification).